==> datanucleus-core-2.0.3-sources.jar: org/datanucleus/store/mapped/scostore/AbstractSetStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import org.datanucleus.StateManager;
import org.datanucleus.store.connection.ManagedConnection;
import org.datanucleus.store.mapped.exceptions.MappedDatastoreException;

/**
 * Specialization interface for {@link AbstractSetStore}.
 * {@link AbstractSetStore} delegates to instances of this interface for behavior
 * that is tied to a specific datastore implementation.
 */
public interface AbstractSetStoreSpecialization extends AbstractCollectionStoreSpecialization
{
    /**
     * @see AbstractSetStore#add
     */
    int[] internalAdd(StateManager sm, ManagedConnection mconn, boolean batched, Object element, boolean processNow,
            AbstractSetStore abstractSetStore) throws MappedDatastoreException;

    /**
     * @see AbstractSetStore#remove
     */
    boolean remove(StateManager sm, Object element, int size, AbstractSetStore setStore);

    void preInternalRemove(ManagedConnection mconn) throws MappedDatastoreException;
}

==> datanucleus-core-2.2.1-sources.jar: org/datanucleus/store/mapped/scostore/AbstractSetStoreSpecialization.java <==
/**********************************************************************
 Copyright (c) 2007 Andy Jefferson and others. All rights reserved.
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 Contributors:
 ...
 **********************************************************************/
package org.datanucleus.store.mapped.scostore;

import org.datanucleus.store.ObjectProvider;
import org.datanucleus.store.connection.ManagedConnection;
import org.datanucleus.store.mapped.exceptions.MappedDatastoreException;

/**
 * Specialization interface for {@link AbstractSetStore}.
 * {@link AbstractSetStore} delegates to instances of this interface for behavior
 * that is tied to a specific datastore implementation.
 */
public interface AbstractSetStoreSpecialization extends AbstractCollectionStoreSpecialization
{
    /**
     * @see AbstractSetStore#add
     */
    int[] internalAdd(ObjectProvider sm, ManagedConnection mconn, boolean batched, Object element, boolean processNow,
            AbstractSetStore abstractSetStore) throws MappedDatastoreException;

    /**
     * @see AbstractSetStore#remove
     */
    boolean remove(ObjectProvider sm, Object element, int size, AbstractSetStore setStore);

    void preInternalRemove(ManagedConnection mconn) throws MappedDatastoreException;
}
